@@ -479,6 +479,14 @@ function (struct command *current)	/* performs a function */
         }
         result = stNUMBER;
         break;
+    case fCEIL:
+        value = ceil(a1->value);
+        result = stNUMBER;
+        break;
+    case fFLOOR:
+	value = floor(a1->value);
+        result = stNUMBER;
+        break;
     case fFRAC:
         if (a1->value < 0) {
             value = a1->value + floor (-a1->value);
@@ -1526,6 +1534,8 @@ peek (char *dest)		/* peek into internals */
     } else if (!strcmp (dest, "secondsrunning")) {
 	time(&now);
 	return now-compilation_start;
+    } else if (!strcmp (dest, "millisrunning")) {
+	return current_millis() - millis_compilation_start;
     } else if (dest[0] == '#') {
         error (ERROR, "don't use quotes when peeking into a file");
         return 0;
@@ -1674,6 +1684,17 @@ exception (struct command *cmd)	/* change handling of exceptions */
 }
 
 
+long long current_millis() {  /* return current number of milliseconds */
+#ifdef WINDOWS
+    return GetTickCount();
+#else
+    struct timespec tsnow;
+    clock_gettime(CLOCK_MONOTONIC, &tsnow);
+    return tsnow.tv_sec*1000LL + tsnow.tv_nsec/1000000LL;
+#endif
+}
+
+
 void
 create_restore (char *label)	/* create command 'restore' */
 {
