@@ -22,9 +22,10 @@
 
 #define DONE {current=current->next;break;}	/* reduces type-work */
 #define COPYRIGHT "Copyright 1995-2018 by Marc Ihm, according to the MIT License"
+/* NOTE: Including whatever timestamp into the banner would break the reproducible build */
 #define BANNER \
 "\nThis is yabasic version " VERSION ",\ncompiled on "\
-ARCHITECTURE " at " __TIMESTAMP__ "\n\n   " COPYRIGHT "\n\n"
+ARCHITECTURE " at " BUILD_TIME "\n\n   " COPYRIGHT "\n\n"
 #define BANNER_VERSION \
 "yabasic " VERSION ", built on " ARCHITECTURE
 #define YABFORHELP "(type 'yabasic --help' for help)"
@@ -89,6 +90,7 @@ static int exitcode = 0;
 static int signal_arrived = 0;
 /* timing */
 time_t compilation_start, compilation_end, execution_end;
+long long int millis_compilation_start;
 char library_path[200];		/* full path to search libraries */
 char library_default[200];	/* default full path to search libraries */
 static struct command *docuhead = NULL;	/* first docu in main */
@@ -210,9 +212,10 @@ main (int argc, char **argv)
 #endif
 
     time (&compilation_start);
+    millis_compilation_start = current_millis();
     last_inkey=my_malloc(INBUFFLEN);
     last_inkey[0]='\0';
-    error (DEBUG, "This is yabasic " VERSION ", compiled on " ARCHITECTURE " at " __TIMESTAMP__ ", configured at " BUILD_TIME);
+    error (DEBUG, "This is yabasic " VERSION ", compiled on " ARCHITECTURE ", configured at " BUILD_TIME);
     initialize ();
     program_state = INITIALIZED;
 
@@ -440,6 +443,7 @@ add_command (int type, char *symname, char *diag)
     new->nextref = NULL;
     new->nextassoc = NULL;
     new->symname = NULL;
+    new->switch_state = NULL;
 
     cmdhead->next = new;
     lastcmd = cmdhead;
